import logging
import boto3
from botocore.exceptions import ClientError


def upload_file(file_name, bucket, object_name=None):
    """Upload a file to an S3 bucket

    :param file_name: File to upload
    :param bucket: Bucket to upload to
    :param object_name: S3 object name. If not specified then file_name is used
    :return: True if file was uploaded, else False
    """

    # If S3 object_name was not specified, use file_name
    if object_name is None:
        object_name = os.path.basename(file_name)

    # Upload the file
    s3_client = boto3.client('s3')
    try:
        response = s3_client.upload_file(file_name, bucket, object_name)
    except ClientError as e:
        logging.error(e)
        return False
    return True


#upload_file("requirements.txt", "diary-profile", "default.jpg")


from pathlib import Path

from setuptools import setup

setup(
    name='shounak_lib',
    description='Python library to upload profile photo',
    long_description=Path('README.md').read_text(),
    long_description_content_type='text/markdown',
    author='Shounak Bhandekar',
    author_email='shounakbhandekar96@gmail.com',
    url='https://github.com/shounak1/shounak_lib',
    version='1.0.1',
    packages=[
        'shounak_lib/sdk'
    ],
    install_requires=['colorama', 'colorlog', 'requests']
)
